@@ -632,6 +632,8 @@ verify_identity (GoaKerberosIdentity  *self,
             verification_level = VERIFICATION_LEVEL_EXISTS;
         }
 
+      krb5_free_cred_contents (self->priv->kerberos_context, &credentials);
+
       error_code = krb5_cc_next_cred (self->priv->kerberos_context,
                                       self->priv->credentials_cache,
                                       &cursor,
@@ -648,9 +650,10 @@ verify_identity (GoaKerberosIdentity  *self,
                                       error_code,
                                       _("Could not sift through identity "
                                         "credentials in cache: %k"));
-      goto out;
+      goto end_sequence;
     }
 
+ end_sequence:
   error_code = krb5_cc_end_seq_get (self->priv->kerberos_context,
                                     self->priv->credentials_cache,
                                     &cursor);
@@ -784,7 +787,6 @@ set_alarm (GoaKerberosIdentity  *self,
 
       new_cancellable = g_cancellable_new ();
       goa_alarm_set_time (alarm, alarm_time, new_cancellable);
-      g_date_time_unref (alarm_time);
 
       g_clear_object (cancellable);
       *cancellable = new_cancellable;
@@ -857,6 +859,7 @@ reset_alarms (GoaKerberosIdentity *self)
   now = g_date_time_new_now_local ();
   expiration_time = g_date_time_new_from_unix_local (self->priv->expiration_time);
   time_span_until_expiration = g_date_time_difference (expiration_time, now);
+  g_date_time_unref (now);
 
   /* Let the user reauthenticate 10 min before expiration */
   expiring_time = g_date_time_add_minutes (expiration_time, -10);
@@ -879,6 +882,9 @@ reset_alarms (GoaKerberosIdentity *self)
              self->priv->expiration_alarm,
              expiration_time, &self->priv->expiration_alarm_cancellable);
 
+  g_date_time_unref (renewal_time);
+  g_date_time_unref (expiring_time);
+  g_date_time_unref (expiration_time);
   connect_alarm_signals (self);
 }
 
@@ -1385,8 +1391,7 @@ goa_kerberos_identity_renew (GoaKerberosIdentity *self, GError **error)
                                       _
                                       ("Could not get new credentials to renew identity %s: %k"),
                                       name);
-      krb5_free_principal (self->priv->kerberos_context, principal);
-      goto out;
+      goto free_principal;
     }
 
   if (!goa_kerberos_identity_update_credentials (self,
@@ -1394,12 +1399,15 @@ goa_kerberos_identity_renew (GoaKerberosIdentity *self, GError **error)
                                                  &new_credentials,
                                                  error))
     {
-      krb5_free_principal (self->priv->kerberos_context, principal);
-      goto out;
+      goto free_principal;
     }
 
   g_debug ("GoaKerberosIdentity: identity %s renewed", name);
   renewed = TRUE;
+
+free_principal:
+  krb5_free_principal (self->priv->kerberos_context, principal);
+
 out:
   g_free (name);
 
